# --Description: Add a prefix and/or a suffix to the name of the selected objects
import sys
import os
import cri.atomcraft.debug as acdebug
import cri.atomcraft.project as acproject

# --BeginUserVariable
"""
OBJECT:
  type:string
  comment:Type of object to rename
PREFIX:
  type:string
  comment:Prefix to add to the name of the object
SUFFIX:
  type:string
  comment:Suffix to add to the name of the object
"""
OBJECT = "Cue"
PREFIX = ""
SUFFIX = ""
# --EndUserVariable

if PREFIX != "" or SUFFIX != "":
	# Get the selected objects
	selected_objects = acproject.get_selected_objects(OBJECT)["data"]

	# Check if the selected objects are of a valid type
	valid_objects = ["Cue", "Material", "CueSheet", "Track"]	# List of valid objects
	if not selected_objects:
		if OBJECT == "":
			acdebug.warning(f"Please specify the object type. Valid types are: {valid_objects}.")
		elif OBJECT not in valid_objects:
			acdebug.warning(f"This is not a valid type for the object. Please use one of these types: {valid_objects}.")
		else:
			acdebug.warning(f"Please select one or several {OBJECT}s.")
		sys.exit()

	elif OBJECT not in valid_objects:
		acdebug.warning(f"Only these types of objects can be renamed: {valid_objects}.")
		sys.exit()

	else:
		for obj in selected_objects:
			object_name = acproject.get_value(obj, "Name")["data"]
			modified_object_name = object_name

			if PREFIX != "":
				modified_object_name = PREFIX + object_name	# Add the prefix if not empty

			if SUFFIX != "":
				base_name, extension = os.path.splitext(modified_object_name)
				modified_object_name = base_name + SUFFIX + extension	# Add the suffix if not empty

			acproject.set_value(obj, "Name", modified_object_name)	# Change the object name to the new name
			acdebug.log(f"{OBJECT} - {object_name} has been renamed to {modified_object_name}")

else:
	acdebug.warning("Please specify a Prefix or a Suffix.")